Flake8 plugin — Radon 1.4.2 documentation

# Flake8 plugin

Radon exposes a plugin for the Flake8 tool. In order to use it you will have to install both radon and flake8.

To enable the Radon checker, you will have to supply at least one of the following options:

`--radon-max-cc``<int>`

  Set the cyclomatic complexity threshold. The default value is 10. Blocks with a greater complexity will be reported by the tool.

`--radon-no-assert```

  Instruct radon not to count assert statements towards cyclomatic complexity. The default behaviour is the opposite.

For more information visit the Flake8 documentation.